﻿using System;
using System.ComponentModel;
using System.Globalization;
using System.Management;

namespace TestProject
{
    /// <summary>
    /// 운영 체제
    /// </summary>
    public class OperatingSystem : Component
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// WMI 네임스페이스
        /// </summary>
        private static string _wmiNamespace = "ROOT\\CIMV2";
        
        /// <summary>
        /// 클래스명
        /// </summary>
        private static string _className = "Win32_OperatingSystem";
        
        /// <summary>
        /// 관리 범위
        /// </summary>
        private static ManagementScope _managementScope = null;

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 관리 시스템 속성
        /// </summary>
        private ManagementSystemProperties managementSystemProperties;
        
        /// <summary>
        /// 관리 객체
        /// </summary>
        private ManagementObject managementObject;
        
        /// <summary>
        /// 자동 커밋 여부
        /// </summary>
        private bool automaticCommit;
        
        /// <summary>
        /// 중첩 관리 기본 객체
        /// </summary>
        private ManagementBaseObject embeddedManagementBaseObject;
        
        /// <summary>
        /// 현재 관리 기본 객체
        /// </summary>
        private ManagementBaseObject currentManagementBaseObject;
        
        /// <summary>
        /// 중첩 여부
        /// </summary>
        private bool isEmbedded;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 원본 네임스페이스 - OriginatingNamespace

        /// <summary>
        /// 원본 네임스페이스
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public string OriginatingNamespace
        {
            get
            {
                return "ROOT\\CIMV2";
            }
        }

        #endregion
        #region 관리 클래스명 - ManagementClassName

        /// <summary>
        /// 관리 클래스명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public string ManagementClassName
        {
            get
            {
                string result = _className;

                if(this.currentManagementBaseObject != null)
                {
                    if(this.currentManagementBaseObject.ClassPath != null)
                    {
                        result = (string)(this.currentManagementBaseObject["__CLASS"]);

                        if((result == null) || (result == string.Empty))
                        {
                            result = _className;
                        }
                    }
                }

                return result;
            }
        }

        #endregion
        #region 시스템 속성 - SystemProperties

        /// <summary>
        /// 시스템 속성
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public ManagementSystemProperties SystemProperties
        {
            get
            {
                return this.managementSystemProperties;
            }
        }

        #endregion
        #region 지연 바인딩 객체 - LateBoundObject

        /// <summary>
        /// 지연 바인딩 객체
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public System.Management.ManagementBaseObject LateBoundObject
        {
            get
            {
                return this.currentManagementBaseObject;
            }
        }

        #endregion
        #region 범위 - Scope

        /// <summary>
        /// 범위
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public ManagementScope Scope
        {
            get
            {
                if(this.isEmbedded == false)
                {
                    return this.managementObject.Scope;
                }
                else
                {
                    return null;
                }
            }
            set
            {
                if(this.isEmbedded == false)
                {
                    this.managementObject.Scope = value;
                }
            }
        }

        #endregion
        #region 자동 커밋 - AutoCommit

        /// <summary>
        /// 자동 커밋
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool AutoCommit
        {
            get
            {
                return this.automaticCommit;
            }
            set
            {
                this.automaticCommit = value;
            }
        }

        #endregion
        #region 경로 - Path

        /// <summary>
        /// 경로
        /// </summary>
        [Browsable(true)]
        public ManagementPath Path
        {
            get
            {
                if(this.isEmbedded == false)
                {
                    return this.managementObject.Path;
                }
                else
                {
                    return null;
                }
            }
            set
            {
                if(this.isEmbedded == false)
                {
                    if(CheckIfProperClass(null, value, null) != true)
                    {
                        throw new System.ArgumentException("Class name does not match.");
                    }

                    this.managementObject.Path = value;
                }
            }
        }

        #endregion
        #region 정적 범위 - StaticScope

        /// <summary>
        /// 정적 범위
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public static System.Management.ManagementScope StaticScope
        {
            get
            {
                return _managementScope;
            }
            set
            {
                _managementScope = value;
            }
        }

        #endregion
        #region 부트 장치 - BootDevice

        /// <summary>
        /// 부트 장치
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The BootDevice property indicates the name of the disk drive from which the Win32 operating system boots. \nExample: \\\\Device\\Harddisk0.")]
        public string BootDevice
        {
            get
            {
                return (string)(this.currentManagementBaseObject["BootDevice"]);
            }
        }

        #endregion
        #region 빌드 번호 - BuildNumber

        /// <summary>
        /// 빌드 번호
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The BuildNumber property indicates the build number of the operating system. It can be used for more precise versioning information than product release version numbers\nExample: 1381")]
        public string BuildNumber
        {
            get
            {
                return (string)(this.currentManagementBaseObject["BuildNumber"]);
            }
        }

        #endregion
        #region 빌드 타입 - BuildType

        /// <summary>
        /// 빌드 타입
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The BuildType property indicates the type of build used for the operating system. Examples are retail build and checked build.")]
        public string BuildType
        {
            get
            {
                return (string)(this.currentManagementBaseObject["BuildType"]);
            }
        }

        #endregion
        #region 제목 - Caption

        /// <summary>
        /// 제목
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Caption property is a short textual description (one-line string) of the object.")]
        public string Caption
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Caption"]);
            }
        }

        #endregion
        #region 코드셋 - CodeSet

        /// <summary>
        /// 코드셋
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The CodeSet property indicates the code page value used by the operating system. A code page contains a character table used by the operating system to translate strings for different languages. The American National Standards Institute (ANSI) lists values that represent defined code pages. If the operating system does not use an ANSI code page, this member will be set to 0. The CodeSet string can use up to six characters to define the code page value. Example : 1255.")]
        public string CodeSet
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CodeSet"]);
            }
        }

        #endregion
        #region 국가 코드 - CountryCode

        /// <summary>
        /// 국가 코드
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The CountryCode property indicates the code for the country/regionused by the operating system. Values are based on international phone dialing prefixes (also referred to as IBM country/region codes). The CountryCode string can use up to six characters to define the country/region code value. Example : 1 for the United States)")]
        public string CountryCode
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CountryCode"]);
            }
        }

        #endregion
        #region 생성 클래스명 - CreationClassName

        /// <summary>
        /// 생성 클래스명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("CreationClassName indicates the name of the class or the subclass used in the creation of an instance. When used with the other key properties of this class, this property allows all instances of this class and its subclasses to be uniquely identified.")]
        public string CreationClassName
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CreationClassName"]);
            }
        }

        #endregion
        #region CS 생성 클래스명 - CSCreationClassName

        /// <summary>
        /// CS 생성 클래스명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("CSCreationClassName contains the scoping computer system\'s creation class name.")]
        public string CSCreationClassName
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CSCreationClassName"]);
            }
        }

        #endregion
        #region CSD 버전 - CSDVersion

        /// <summary>
        /// CSD 버전
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The CSDVersion property contains a null-terminated string, that indicates the latest Service Pack installed on the computer system. If no Service Pack is installed, the string is NULL. For computer systems running Windows 95, this property contains a null-terminated string that provides arbitrary additional information about the operating system. Example : Service Pack 3.")]
        public string CSDVersion
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CSDVersion"]);
            }
        }

        #endregion
        #region CS명 - CSName

        /// <summary>
        /// CS명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("CSName contains the scoping computer system\'s name.")]
        public string CSName
        {
            get
            {
                return (string)(this.currentManagementBaseObject["CSName"]);
            }
        }

        #endregion
        #region 현재 타임존 NULL 여부 - IsCurrentTimeZoneNull

        /// <summary>
        /// 현재 타임존 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsCurrentTimeZoneNull
        {
            get
            {
                if(this.currentManagementBaseObject["CurrentTimeZone"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 현재 타임존 - CurrentTimeZone

        /// <summary>
        /// 현재 타임존
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("CurrentTimeZone indicates the number of minutes the operating system is offset from Greenwich Mean Time. Either the number is positive, negative or zero.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public short CurrentTimeZone
        {
            get
            {
                if(this.currentManagementBaseObject["CurrentTimeZone"] == null)
                {
                    return Convert.ToInt16(0);
                }

                return (short)(this.currentManagementBaseObject["CurrentTimeZone"]);
            }
        }

        #endregion
        #region 32비트 어플리케이션 데이터 실행 금지 NULL 여부 - IsDataExecutionPrevention_32BitApplicationsNull

        /// <summary>
        /// 32비트 어플리케이션 데이터 실행 금지 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDataExecutionPrevention_32BitApplicationsNull
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_32BitApplications"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 32비트 어플리케이션 데이터 실행 금지 여부 - DataExecutionPrevention_32BitApplications

        /// <summary>
        /// 32비트 어플리케이션 데이터 실행 금지 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("If true, indicates that 32-bit applications are running with Data Execution Prevention (DEP) applied. (false if DataExecutionPrevention_Available = false)")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool DataExecutionPrevention_32BitApplications
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_32BitApplications"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["DataExecutionPrevention_32BitApplications"]);
            }
        }

        #endregion
        #region 이용 가능 데이터 실행 금지 NULL 여부 - IsDataExecutionPrevention_AvailableNull

        /// <summary>
        /// 이용 가능 데이터 실행 금지 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDataExecutionPrevention_AvailableNull
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_Available"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 이용 가능 데이터 실행 금지 여부 - DataExecutionPrevention_Available

        /// <summary>
        /// 이용 가능 데이터 실행 금지 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description(@"If true, indicates that the hardware supports Windows Data Execution Prevention (DEP) technology. DEP ensures that all memory locations are marked with a non-executable attribute unless the memory location explicitly contains executable code.  This can help mitigate certain types of buffer overrun security exploits.  If DEP is available, 64-bit applications are automatically protected.  To determine if DEP has been enabled for 32-bit applications and drivers, use the DataExecutionPrevention_ properties ")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool DataExecutionPrevention_Available
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_Available"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["DataExecutionPrevention_Available"]);
            }
        }

        #endregion
        #region 드라이버 데이터 실행 금지 NULL 여부 - IsDataExecutionPrevention_DriversNull

        /// <summary>
        /// 드라이버 데이터 실행 금지 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDataExecutionPrevention_DriversNull
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_Drivers"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 드라이버 데이터 실행 금지 여부 - DataExecutionPrevention_Drivers

        /// <summary>
        /// 드라이버 데이터 실행 금지 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("If true, indicates that drivers are running with Data Execution Prevention (DEP) applied. (false if DataExecutionPrevention_Available = false)")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool DataExecutionPrevention_Drivers
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_Drivers"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["DataExecutionPrevention_Drivers"]);
            }
        }

        #endregion
        #region 정책 지원 데이터 실행 금지 NULL 여부 - IsDataExecutionPrevention_SupportPolicyNull

        /// <summary>
        /// 정책 지원 데이터 실행 금지 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDataExecutionPrevention_SupportPolicyNull
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_SupportPolicy"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 정책 지원 데이터 실행 금지 여부 - DataExecutionPrevention_SupportPolicy

        /// <summary>
        /// 정책 지원 데이터 실행 금지 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The DataExecutionPrevention_SupportPolicy indicates which one of four Data Execution Prevention (DEP) settings is applied. Each setting varies by the extent to which DEP is applied to 32-bit applications.  Note that DEP is always applied to the Windows kernel. Always On (not available in the user interface) indicates that DEP is enabled for all 32-bit applications on the machine with no exceptions. OptOut indicates DEP is on by default for all 32-bit applications and that a user or administrator must explicitly remove support for a 32-bit application by adding to an exceptions list. OptIn indicates DEP is on for a limited number of binaries, the kernel, and all Windows services but it is off by default for all 32-bit applications; a user or administrator must explicitly choose the AlwaysOn (not available in the user interface) or OptOut setting before DEP can be applied to 32-bit applications. AlwaysOff (not available in the user interface) indicates DEP is turned off for all 32-bit applications on the machine.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public DataExecutionPrevention_SupportPolicyValue DataExecutionPrevention_SupportPolicy
        {
            get
            {
                if(this.currentManagementBaseObject["DataExecutionPrevention_SupportPolicy"] == null)
                {
                    return (DataExecutionPrevention_SupportPolicyValue)(Convert.ToInt32(4));
                }

                return (DataExecutionPrevention_SupportPolicyValue)(Convert.ToInt32(this.currentManagementBaseObject["DataExecutionPrevention_SupportPolicy"]));
            }
        }

        #endregion
        #region 디버그 NULL 여부 - IsDebugNull

        /// <summary>
        /// 디버그 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDebugNull
        {
            get
            {
                if(this.currentManagementBaseObject["Debug"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 디버그 여부 - Debug

        /// <summary>
        /// 디버그 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Debug property indicates whether the operating system is a checked (debug) build. Checked builds provide error checking, argument verification, and system debugging code. Additional code in a checked binary generates a kernel debugger error message and breaks into the debugger. This helps  immediately determine the cause and location of the error. Performance suffers in the checked build due to the additional code that is executed. Values : TRUE or FALSE, A value of TRUE indicates the debugging version of User.exe is installed.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool Debug
        {
            get
            {
                if(this.currentManagementBaseObject["Debug"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["Debug"]);
            }
        }

        #endregion
        #region 설명 - Description

        /// <summary>
        /// 설명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Description property provides a description of the Windows operating system. Some user interfaces (those that allow editing of this description) limit its length to 48 characters.")]
        public string Description
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Description"]);
            }
            set
            {
                this.currentManagementBaseObject["Description"] = value;

                if((this.isEmbedded == false) && (this.automaticCommit == true))
                {
                    this.managementObject.Put();
                }
            }
        }

        #endregion
        #region 분산 NULL 여부 - IsDistributedNull

        /// <summary>
        /// 분산 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsDistributedNull
        {
            get
            {
                if(this.currentManagementBaseObject["Distributed"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 분산 여부 - Distributed

        /// <summary>
        /// 분산 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Boolean indicating whether the operating system is distributed across several computer system nodes. If so, these nodes should be grouped as a cluster.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool Distributed
        {
            get
            {
                if(this.currentManagementBaseObject["Distributed"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["Distributed"]);
            }
        }

        #endregion
        #region 암호화 레벨 NULL 여부 - IsEncryptionLevelNull

        /// <summary>
        /// 암호화 레벨 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsEncryptionLevelNull
        {
            get
            {
                if(this.currentManagementBaseObject["EncryptionLevel"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 암호화 레벨 - EncryptionLevel

        /// <summary>
        /// 암호화 레벨
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The EncryptionLevel property specifies if the encryption level for secure transactions is 40-bit, 128-bit, or n-bit encryption.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public EncryptionLevelValue EncryptionLevel
        {
            get
            {
                if(this.currentManagementBaseObject["EncryptionLevel"] == null)
                {
                    return (EncryptionLevelValue)(Convert.ToInt32(3));
                }

                return (EncryptionLevelValue)(Convert.ToInt32(this.currentManagementBaseObject["EncryptionLevel"]));
            }
        }

        #endregion
        #region 전경 어플리케이션 부스트 NULL 여부 - IsForegroundApplicationBoostNull

        /// <summary>
        /// 전경 어플리케이션 부스트 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsForegroundApplicationBoostNull
        {
            get
            {
                if(this.currentManagementBaseObject["ForegroundApplicationBoost"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 전경 어플리케이션 부스트 - ForegroundApplicationBoost

        /// <summary>
        /// 전경 어플리케이션 부스트
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The ForegroundApplicationBoost property indicates the increase in priority given to the foreground application. On computer systems running Windows NT 4.0 and Windows 2000, application boost is implemented by giving an application more execution time slices (quantum lengths). A ForegroundApplicationBoost value of 0 indicates the system boosts the quantum length by 6; if 1, then 12; and if 2 then 18. On Windows NT 3.51 and earlier, application boost is implemented by increasing the scheduling priority. For these systems, the scheduling priority is increased by the value of this property. The default value is 2.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ForegroundApplicationBoostValue ForegroundApplicationBoost
        {
            get
            {
                if(this.currentManagementBaseObject["ForegroundApplicationBoost"] == null)
                {
                    return (ForegroundApplicationBoostValue)(Convert.ToInt32(3));
                }

                return (ForegroundApplicationBoostValue)(Convert.ToInt32(this.currentManagementBaseObject["ForegroundApplicationBoost"]));
            }
            set
            {
                if(ForegroundApplicationBoostValue.Null == value)
                {
                    this.currentManagementBaseObject["ForegroundApplicationBoost"] = null;
                }
                else
                {
                    this.currentManagementBaseObject["ForegroundApplicationBoost"] = value;
                }

                if((this.isEmbedded == false) && (this.automaticCommit == true))
                {
                    this.managementObject.Put();
                }
            }
        }

        #endregion
        #region 프리 물리 메모리 NULL 여부 - IsFreePhysicalMemoryNull

        /// <summary>
        /// 프리 물리 메모리 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsFreePhysicalMemoryNull
        {
            get
            {
                if(this.currentManagementBaseObject["FreePhysicalMemory"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 프리 물리 메모리 - FreePhysicalMemory

        /// <summary>
        /// 프리 물리 메모리
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of kilobytes of physical memory currently unused and available")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong FreePhysicalMemory
        {
            get
            {
                if(this.currentManagementBaseObject["FreePhysicalMemory"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["FreePhysicalMemory"]);
            }
        }

        #endregion
        #region 페이징 파일 프리 공간 NULL 여부 - IsFreeSpaceInPagingFilesNull

        /// <summary>
        /// 페이징 파일 프리 공간 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsFreeSpaceInPagingFilesNull
        {
            get
            {
                if(this.currentManagementBaseObject["FreeSpaceInPagingFiles"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 페이징 파일 프리 공간 - FreeSpaceInPagingFiles

        ///페이징 파일 프리 공간        
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The total number of KBytes that can be mapped into the OperatingSystem\'s paging files without causing any other pages to be swapped out. 0 indicates that there are no paging files.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong FreeSpaceInPagingFiles
        {
            get
            {
                if(this.currentManagementBaseObject["FreeSpaceInPagingFiles"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["FreeSpaceInPagingFiles"]);
            }
        }

        #endregion
        #region 프리 가상 메모리 NULL 여부 - IsFreeVirtualMemoryNull

        /// <summary>
        /// 프리 가상 메모리 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsFreeVirtualMemoryNull
        {
            get
            {
                if(this.currentManagementBaseObject["FreeVirtualMemory"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 프리 가상 메모리 - FreeVirtualMemory

        /// <summary>
        /// 프리 가상 메모리
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of kilobytes of virtual memory currently unused and available. For example, this may be calculated by adding the amount of free RAM to the amount of free paging space (i.e., adding the properties, FreePhysicalMemory and FreeSpaceInPagingFiles).")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong FreeVirtualMemory
        {
            get
            {
                if(this.currentManagementBaseObject["FreeVirtualMemory"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["FreeVirtualMemory"]);
            }
        }

        #endregion
        #region 설치일 NULL 여부 - IsInstallDateNull

        /// <summary>
        /// 설치일 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsInstallDateNull
        {
            get
            {
                if(this.currentManagementBaseObject["InstallDate"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 설치일 - InstallDate

        /// <summary>
        /// 설치일
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The InstallDate property is datetime value indicating when the object was installed. A lack of a value does not indicate that the object is not installed.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public DateTime InstallDate
        {
            get
            {
                if(this.currentManagementBaseObject["InstallDate"] != null)
                {
                    return ToDateTime(((string)(this.currentManagementBaseObject["InstallDate"])));
                }
                else
                {
                    return DateTime.MinValue;
                }
            }
        }

        #endregion
        #region 큰 시스템 캐시 NULL 여부 - IsLargeSystemCacheNull

        /// <summary>
        /// 큰 시스템 캐시 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsLargeSystemCacheNull
        {
            get
            {
                if(this.currentManagementBaseObject["LargeSystemCache"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 큰 시스템 캐시 - LargeSystemCache

        /// <summary>
        /// 큰 시스템 캐시
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The LargeSystemCache property indicates whether to optimize memory for applications (value=0) or for system performance (value=1).")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public LargeSystemCacheValue LargeSystemCache
        {
            get
            {
                if(this.currentManagementBaseObject["LargeSystemCache"] == null)
                {
                    return (LargeSystemCacheValue)(Convert.ToInt32(2));
                }

                return (LargeSystemCacheValue)(Convert.ToInt32(this.currentManagementBaseObject["LargeSystemCache"]));
            }
        }

        #endregion
        #region 마지막 부트 업 시간 NULL 여부 - IsLastBootUpTimeNull

        /// <summary>
        /// 마지막 부트 업 시간 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsLastBootUpTimeNull
        {
            get
            {
                if(this.currentManagementBaseObject["LastBootUpTime"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 마지막 부트 업 시간 - LastBootUpTime

        /// <summary>
        /// 마지막 부트 업 시간
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Time when the operating system was last booted")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public DateTime LastBootUpTime
        {
            get
            {
                if(this.currentManagementBaseObject["LastBootUpTime"] != null)
                {
                    return ToDateTime((string)(this.currentManagementBaseObject["LastBootUpTime"]));
                }
                else
                {
                    return DateTime.MinValue;
                }
            }
        }

        #endregion
        #region 로컬 시간/일시 NULL 여부 - IsLocalDateTimeNull

        /// <summary>
        /// 로컬 시간/일시 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsLocalDateTimeNull
        {
            get
            {
                if(this.currentManagementBaseObject["LocalDateTime"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 로컬 시간/일시 - LocalDateTime

        /// <summary>
        /// 로컬 시간/일시
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Operating system\'s notion of the local date and time of day.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public DateTime LocalDateTime
        {
            get
            {
                if(this.currentManagementBaseObject["LocalDateTime"] != null)
                {
                    return ToDateTime((string)(this.currentManagementBaseObject["LocalDateTime"]));
                }
                else
                {
                    return DateTime.MinValue;
                }
            }
        }

        #endregion
        #region 로케일 - Locale

        /// <summary>
        /// 로케일
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Locale property indicates the language identifier used by the operating system. A language identifier is a standard international numeric abbreviation for a country or region. Each language has a unique language identifier (LANGID), a 16-bit value that consists of a primary language identifier and a secondary language identifier.")]
        public string Locale
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Locale"]);
            }
        }

        #endregion
        #region 제조자 - Manufacturer

        /// <summary>
        /// 제조자
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Manufacturer property indicates the name of the operating system manufacturer. For Win32 systems this value will be Microsoft Corporation.")]
        public string Manufacturer
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Manufacturer"]);
            }
        }

        #endregion
        #region 프로세스 최대 수 NULL 여부 - IsMaximumProcessCountNull

        /// <summary>
        /// 프로세스 최대 수 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsMaximumProcessCountNull
        {
            get
            {
                if(this.currentManagementBaseObject["MaxNumberOfProcesses"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 프로세스 최대 수 - MaximumProcessCount

        /// <summary>
        /// 프로세스 최대 수
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description(@"Maximum number of process contexts the operating system can support. If there is no fixed maximum, the value should be 0. On systems that have a fixed maximum, this object can help diagnose failures that occur when the maximum is reached. If unknown, enter -1.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint MaximumProcessCount
        {
            get
            {
                if(this.currentManagementBaseObject["MaxNumberOfProcesses"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["MaxNumberOfProcesses"]);
            }
        }

        #endregion
        #region 최대 프로세스 메모리 크기 NULL 여부 - IsMaximumProcessMemorySizeNull

        /// <summary>
        /// 최대 프로세스 메모리 크기 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsMaximumProcessMemorySizeNull
        {
            get
            {
                if(this.currentManagementBaseObject["MaxProcessMemorySize"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 최대 프로세스 메모리 크기 - MaximumProcessMemorySize

        /// <summary>
        /// 최대 프로세스 메모리 크기
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description(@"Maximum number of kilobytes of memory that can be allocated to a process. For operating systems with no virtual memory, this value is typically equal to the total amount of physical memory minus memory used by the BIOS and OS. For some operating systems, this value may be infinity - in which case, 0 should be entered. In other cases, this value could be a constant - for example, 2G or 4G.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong MaximumProcessMemorySize
        {
            get
            {
                if(this.currentManagementBaseObject["MaxProcessMemorySize"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["MaxProcessMemorySize"]);
            }
        }

        #endregion
        #region MUI 언어 배열 - MUILanguageArray

        /// <summary>
        /// MUI 언어 배열
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The MUILanguages property indicates the MUI Languages installed in the system. Example : en-us.")]
        public string[] MUILanguageArray
        {
            get
            {
                return (string[])(this.currentManagementBaseObject["MUILanguages"]);
            }
        }

        #endregion
        #region 운영 체제 인스턴스명 - Name

        /// <summary>
        /// 운영 체제 인스턴스명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Name of the operating system instance within a computer system.")]
        public string Name
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Name"]);
            }
        }

        #endregion
        #region 라이센스 사용자 수 NULL 여부 - IsLicensedUserCountNull

        /// <summary>
        /// 라이센스 사용자 수 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsLicensedUserCountNull
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfLicensedUsers"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 라이센스 사용자 수 - LicensedUserCount

        /// <summary>
        /// 라이센스 사용자 수
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of user licenses for the operating system. If unlimited, enter 0. If unknown, enter -1.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint LicensedUserCount
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfLicensedUsers"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["NumberOfLicensedUsers"]);
            }
        }

        #endregion
        #region 프로세스 수 NULL 여부 - IsProcessCountNull

        /// <summary>
        /// 프로세스 수 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsProcessCountNull
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfProcesses"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 프로세스 수 - ProcessCount

        /// <summary>
        /// 프로세스 수
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of process contexts currently loaded or running on the operating system.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint ProcessCount
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfProcesses"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["NumberOfProcesses"]);
            }
        }

        #endregion
        #region 사용자 수 NULL 여부 - IsUserCountNull

        /// <summary>
        /// 사용자 수 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsUserCountNull
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfUsers"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 사용자 수 - UserCount

        /// <summary>
        /// 사용자 수
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of user sessions for which the operating system is currently storing state information")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint UserCount
        {
            get
            {
                if(this.currentManagementBaseObject["NumberOfUsers"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["NumberOfUsers"]);
            }
        }

        #endregion
        #region 운영 체제 SKU NULL 여부 - IsOperatingSystemSKUNull

        /// <summary>
        /// 운영 체제 SKU NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsOperatingSystemSKUNull
        {
            get
            {
                if(this.currentManagementBaseObject["OperatingSystemSKU"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 운영 체제 SKU - OperatingSystemSKU

        /// <summary>
        /// 운영 체제 SKU
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The OperatingSystemSKU property identifies the SKU of the operating system.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint OperatingSystemSKU
        {
            get
            {
                if(this.currentManagementBaseObject["OperatingSystemSKU"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["OperatingSystemSKU"]);
            }
        }

        #endregion
        #region 조직 - Organization

        /// <summary>
        /// 조직
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Organization property indicates the registered user\'s (of the operating system) company name.\nExample: Microsoft Corporation.")]
        public string Organization
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Organization"]);
            }
        }

        #endregion
        #region 운영 체제 아키텍처 - OSArchitecture

        /// <summary>
        /// 운영 체제 아키텍처
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The OSArchitecture property indicates the Architecture of the operating system.Example : 32-bit, 64-bit Intel, 64-bit AMD ")]
        public string OSArchitecture
        {
            get
            {
                return (string)(this.currentManagementBaseObject["OSArchitecture"]);
            }
        }

        #endregion
        #region 운영 체제 언어 NULL 여부 - IsOSLanguageNull

        /// <summary>
        /// 운영 체제 언어 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsOSLanguageNull
        {
            get
            {
                if(this.currentManagementBaseObject["OSLanguage"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 운영 체제 언어 - OSLanguage

        /// <summary>
        /// 운영 체제 언어
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The OSLanguage property indicates which language version of the operating system is installed.\nExample: 0x0807 (German, Switzerland)")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public uint OSLanguage
        {
            get
            {
                if(this.currentManagementBaseObject["OSLanguage"] == null)
                {
                    return Convert.ToUInt32(0);
                }

                return (uint)(this.currentManagementBaseObject["OSLanguage"]);
            }
        }

        #endregion
        #region 운영 체제 제품 슈트 NULL 여부 - IsOSProductSuiteNull

        /// <summary>
        /// 운영 체제 제품 슈트 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsOSProductSuiteNull
        {
            get
            {
                if(this.currentManagementBaseObject["OSProductSuite"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 운영 체제 제품 슈트 - OSProductSuite

        /// <summary>
        /// 운영 체제 제품 슈트
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The OSProductSuite property identifies installed and licensed system product additions to the operating system.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public OSProductSuiteValue OSProductSuite
        {
            get
            {
                if(this.currentManagementBaseObject["OSProductSuite"] == null)
                {
                    return (OSProductSuiteValue)(Convert.ToInt32(256));
                }

                return (OSProductSuiteValue)(Convert.ToInt32(this.currentManagementBaseObject["OSProductSuite"]));
            }
        }

        #endregion
        #region 운영 체제 타입 NULL 여부 - IsOSTypeNull

        /// <summary>
        /// 운영 체제 타입 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsOSTypeNull
        {
            get
            {
                if(this.currentManagementBaseObject["OSType"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 운영 체제 타입 - OSType

        /// <summary>
        /// 운영 체제 타입
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("A integer indicating the type of operating system.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public OSTypeValue OSType
        {
            get
            {
                if(this.currentManagementBaseObject["OSType"] == null)
                {
                    return (OSTypeValue)(Convert.ToInt32(63));
                }

                return (OSTypeValue)(Convert.ToInt32(this.currentManagementBaseObject["OSType"]));
            }
        }

        #endregion
        #region 다른 타입 설명 - OtherTypeDescription

        /// <summary>
        /// 다른 타입 설명
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("A string describing the manufacturer and operating system type - used when the operating system property, OSType, is set to 1 (\"Other\"). The format of the string inserted in OtherTypeDescription should be similar in format to the Values strings defined for OSType.  OtherTypeDescription should be set to NULL when OSType is any value other than 1.")]
        public string OtherTypeDescription
        {
            get
            {
                return (string)(this.currentManagementBaseObject["OtherTypeDescription"]);
            }
        }

        #endregion
        #region PAE 이용 가능 여부 NULL 여부 - IsPAEEnabledNull

        /// <summary>
        /// PAE 이용 가능 여부 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsPAEEnabledNull
        {
            get
            {
                if(this.currentManagementBaseObject["PAEEnabled"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region PAE 이용 가능 여부 - PAEEnabled

        /// <summary>
        /// PAE 이용 가능 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool PAEEnabled
        {
            get
            {
                if(this.currentManagementBaseObject["PAEEnabled"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["PAEEnabled"]);
            }
        }

        #endregion
        #region 플러스 제품 ID - PlusProductID

        /// <summary>
        /// 플러스 제품 ID
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The PlusProductID property contains the product identification number for the Windows Plus! operating system enhancement software (if installed).")]
        public string PlusProductID
        {
            get
            {
                return (string)(this.currentManagementBaseObject["PlusProductID"]);
            }
        }

        #endregion
        #region 플러스 버전 번호 - PlusVersionNumber

        /// <summary>
        /// 플러스 버전 번호
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The PlusVersionNumber property contains the version number of the Windows Plus! operating system enhancement software (if installed).")]
        public string PlusVersionNumber
        {
            get
            {
                return (string)(this.currentManagementBaseObject["PlusVersionNumber"]);
            }
        }

        #endregion
        #region 메인 여부 NULL 여부 - IsPrimaryNull

        /// <summary>
        /// 메인 여부 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsPrimaryNull
        {
            get
            {
                if(this.currentManagementBaseObject["Primary"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 메인 여부 - Primary

        /// <summary>
        /// 메인 여부
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Primary property determines whether this is the primary operating system.\nValues : TRUE or FALSE. A value of TRUE indicates this is the primary operating system.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public bool Primary
        {
            get
            {
                if(this.currentManagementBaseObject["Primary"] == null)
                {
                    return Convert.ToBoolean(0);
                }

                return (bool)(this.currentManagementBaseObject["Primary"]);
            }
        }

        #endregion
        #region 제품 타입 NULL 여부 - IsProductTypeNull

        /// <summary>
        /// 제품 타입 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsProductTypeNull
        {
            get
            {
                if(this.currentManagementBaseObject["ProductType"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 제품 타입 - ProductType

        /// <summary>
        /// 제품 타입
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The ProductType property indicates additional information about the system. This member can be one of the following values: \n1 - Work Station \n2 - Domain Controller \n3 - Server")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ProductTypeValue ProductType
        {
            get
            {
                if(this.currentManagementBaseObject["ProductType"] == null)
                {
                    return (ProductTypeValue)(Convert.ToInt32(0));
                }

                return (ProductTypeValue)(Convert.ToInt32(this.currentManagementBaseObject["ProductType"]));
            }
        }

        #endregion
        #region 등록 사용자 - RegisteredUser

        /// <summary>
        /// 등록 사용자
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The RegisteredUser property indicates the name of the registered user of the operating system.\nExample : Jane Doe")]
        public string RegisteredUser
        {
            get
            {
                return (string)(this.currentManagementBaseObject["RegisteredUser"]);
            }
        }

        #endregion
        #region 시리얼 번호 - SerialNumber

        /// <summary>
        /// 시리얼 번호
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The SerialNumber property indicates the operating system product serial identification number.\nExample:10497-OEM-0031416-71674.")]
        public string SerialNumber
        {
            get
            {
                return (string)(this.currentManagementBaseObject["SerialNumber"]);
            }
        }

        #endregion
        #region 서비스 팩 메이저 버전 NULL 여부 - IsServicePackMajorVersionNull

        /// <summary>
        /// 서비스 팩 메이저 버전 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsServicePackMajorVersionNull
        {
            get
            {
                if(this.currentManagementBaseObject["ServicePackMajorVersion"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 서비스 팩 메이저 버전 - ServicePackMajorVersion

        /// <summary>
        /// 서비스 팩 메이저 버전
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The ServicePackMajorVersion property indicates the major version number of the service pack installed on the computer system. If no service pack has been installed, the value is zero. ServicePackMajorVersion is valid for computers running Windows 2000 and later (NULL otherwise).")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ushort ServicePackMajorVersion
        {
            get
            {
                if(this.currentManagementBaseObject["ServicePackMajorVersion"] == null)
                {
                    return Convert.ToUInt16(0);
                }
                
                return (ushort)(this.currentManagementBaseObject["ServicePackMajorVersion"]);
            }
        }

        #endregion
        #region 서비스 팩 마이너 버전 NULL 여부 - IsServicePackMinorVersionNull

        /// <summary>
        /// 서비스 팩 마이너 버전 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsServicePackMinorVersionNull
        {
            get
            {
                if(this.currentManagementBaseObject["ServicePackMinorVersion"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 서비스 팩 마이너 버전 - ServicePackMinorVersion

        /// <summary>
        /// 서비스 팩 마이너 버전
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The ServicePackMinorVersion property indicates the minor version number of the service pack installed on the computer system. If no service pack has been installed, the value is zero. ServicePackMinorVersion is valid for computers running Windows 2000 and later (NULL otherwise).")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ushort ServicePackMinorVersion
        {
            get
            {
                if(this.currentManagementBaseObject["ServicePackMinorVersion"] == null)
                {
                    return Convert.ToUInt16(0);
                }

                return (ushort)(this.currentManagementBaseObject["ServicePackMinorVersion"]);
            }
        }

        #endregion
        #region 페이징 파일 저장 크기 NULL 여부 - IsSizeStoredInPagingFilesNull

        /// <summary>
        /// 페이징 파일 저장 크기 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsSizeStoredInPagingFilesNull
        {
            get
            {
                if(this.currentManagementBaseObject["SizeStoredInPagingFiles"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 페이징 파일 저장 크기 - SizeStoredInPagingFiles

        /// <summary>
        /// 페이징 파일 저장 크기
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The total number of kilobytes that can be stored in the operating system\'s paging files. Note that this number does not represent the actual physical size of the paging file on disk.  0 indicates that there are no paging files.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong SizeStoredInPagingFiles
        {
            get
            {
                if(this.currentManagementBaseObject["SizeStoredInPagingFiles"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["SizeStoredInPagingFiles"]);
            }
        }

        #endregion
        #region 상태 - Status

        /// <summary>
        /// 상태
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Status property is a string indicating the current status of the object. Various operational and non-operational statuses can be defined. Operational statuses are \"OK\", \"Degraded\" and \"Pred Fail\". \"Pred Fail\" indicates that an element may be functioning properly but predicting a failure in the near future. An example is a SMART-enabled hard drive. Non-operational statuses can also be specified. These are \"Error\", \"Starting\", \"Stopping\" and \"Service\". The latter, \"Service\", could apply during mirror-resilvering of a disk, reload of a user permissions list, or other administrative work. Not all such work is on-line, yet the managed element is neither \"OK\" nor in one of the other states.")]
        public string Status
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Status"]);
            }
        }

        #endregion
        #region 슈트 마스크 NULL 여부 - IsSuiteMaskNull

        /// <summary>
        /// 슈트 마스크 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsSuiteMaskNull
        {
            get
            {
                if(this.currentManagementBaseObject["SuiteMask"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 슈트 마스크 - SuiteMask

        /// <summary>
        /// 슈트 마스크
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description(@"The SuiteMask property indicates a set of bit flags that identify the product suites available on the system. This member can be a combination of the following values: 
0 - Windows Server 2003, Small Business Edition 
1 - Windows Server 2003, Enterprise Edition 
2 - Windows Server 2003, Backoffice Edition 
3 - Windows Server 2003, Communications Edition 
4 - Microsoft Terminal Services 
5 - Windows Server 2003, Small Business Edition Restricted 
6 - Windows XP Embedded 
7 - Windows Server 2003, Datacenter Edition 
8 - Single User 
9 - Windows XP Home Edition 
10 - Windows Server 2003, Web Edition")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public SuiteMaskValue SuiteMask
        {
            get
            {
                if(this.currentManagementBaseObject["SuiteMask"] == null)
                {
                    return (SuiteMaskValue)(Convert.ToInt32(20));
                }

                return (SuiteMaskValue)(Convert.ToInt32(this.currentManagementBaseObject["SuiteMask"]));
            }
        }

        #endregion
        #region 시스템 장치 - SystemDevice

        /// <summary>
        /// 시스템 장치
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The SystemDevice property indicates the physical disk partition the operating system is installed on.")]
        public string SystemDevice
        {
            get
            {
                return (string)(this.currentManagementBaseObject["SystemDevice"]);
            }
        }

        #endregion
        #region 시스템 디렉토리 - SystemDirectory

        /// <summary>
        /// 시스템 디렉토리
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The SystemDirectory property indicates the system directory of the operating system.\nExample : C:\\WINDOWS\\SYSTEM32")]
        public string SystemDirectory
        {
            get
            {
                return (string)(this.currentManagementBaseObject["SystemDirectory"]);
            }
        }

        #endregion
        #region 시스템 드라이브 - SystemDrive

        /// <summary>
        /// 시스템 드라이브
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The SystemDrive property contains the letter of the disk drive that the operating system resides on.\nExample : C:")]
        public string SystemDrive
        {
            get
            {
                return (string)(this.currentManagementBaseObject["SystemDrive"]);
            }
        }

        #endregion
        #region 전체 스왑 공간 크기 NULL 여부 - IsTotalSwapSpaceSizeNull

        /// <summary>
        /// 전체 스왑 공간 크기 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsTotalSwapSpaceSizeNull
        {
            get
            {
                if(this.currentManagementBaseObject["TotalSwapSpaceSize"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 전체 스왑 공간 크기 - TotalSwapSpaceSize

        /// <summary>
        /// 전체 스왑 공간 크기
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Total swap space in kilobytes. This value may be NULL (unspecified) if swap space is not distinguished from page files.  However, some operating systems distinguish these concepts.  For example, in UNIX, whole processes can be 'swapped out' when the free page list falls and remains below a specified amount.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong TotalSwapSpaceSize
        {
            get
            {
                if(this.currentManagementBaseObject["TotalSwapSpaceSize"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["TotalSwapSpaceSize"]);
            }
        }

        #endregion
        #region 전체 가상 메모리 크기 NULL 여부 - IsTotalVirtualMemorySizeNull

        /// <summary>
        /// 전체 가상 메모리 크기 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsTotalVirtualMemorySizeNull
        {
            get
            {
                if(this.currentManagementBaseObject["TotalVirtualMemorySize"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 전체 가상 메모리 크기 - TotalVirtualMemorySize

        /// <summary>
        /// 전체 가상 메모리 크기
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("Number of kilobytes of virtual memory. For example, this may be calculated by adding the amount of total RAM to the amount of paging space (i.e., adding the amount of memory in/aggregated by the computer system to the property, SizeStoredInPagingFiles.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong TotalVirtualMemorySize
        {
            get
            {
                if(this.currentManagementBaseObject["TotalVirtualMemorySize"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["TotalVirtualMemorySize"]);
            }
        }

        #endregion
        #region 전체 표시 메모리 크기 NULL 여부 - IsTotalVisibleMemorySizeNull

        /// <summary>
        /// 전체 표시 메모리 크기 NULL 여부
        /// </summary>
        [Browsable(false)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool IsTotalVisibleMemorySizeNull
        {
            get
            {
                if(this.currentManagementBaseObject["TotalVisibleMemorySize"] == null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        #endregion
        #region 전체 표시 메모리 크기 - TotalVisibleMemorySize

        /// <summary>
        /// 전체 표시 메모리 크기
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The total amount of physical memory (in Kbytes) available to the OperatingSystem. This value does not necessarily indicate the true amount of physical memory, but what is reported to the OperatingSystem as available to it.")]
        [TypeConverter(typeof(WMIValueTypeConverter))]
        public ulong TotalVisibleMemorySize
        {
            get
            {
                if(this.currentManagementBaseObject["TotalVisibleMemorySize"] == null)
                {
                    return Convert.ToUInt64(0);
                }

                return (ulong)(this.currentManagementBaseObject["TotalVisibleMemorySize"]);
            }
        }

        #endregion
        #region 버전 - Version

        /// <summary>
        /// 버전
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The Version property indicates the version number of the operating system.\nExample : 4.0")]
        public string Version
        {
            get
            {
                return (string)(this.currentManagementBaseObject["Version"]);
            }
        }

        #endregion
        #region 윈도우즈 디렉토리 - WindowsDirectory

        /// <summary>
        /// 윈도우즈 디렉토리
        /// </summary>
        [Browsable(true)]
        [DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        [Description("The WindowsDirectory property indicates the Windows directory of the operating system.\nExample : C:\\WINDOWS")]
        public string WindowsDirectory
        {
            get
            {
                return (string)(this.currentManagementBaseObject["WindowsDirectory"]);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Consturctor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - OperatingSystem()

        /// <summary>
        /// 생성자
        /// </summary>
        public OperatingSystem()
        {
            InitializeObject(null, new ManagementPath(OperatingSystem.ConstructPath()), null);
        }

        #endregion
        #region 생성자 - OperatingSystem(managementScope)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementScope">관리 범위</param>
        public OperatingSystem(ManagementScope managementScope)
        {
            InitializeObject(managementScope, new ManagementPath(OperatingSystem.ConstructPath()), null);
        }

        #endregion
        #region 생성자 - OperatingSystem(managementPath)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementPath">관리 경로</param>
        public OperatingSystem(ManagementPath managementPath)
        {
            InitializeObject(null, managementPath, null);
        }

        #endregion
        #region 생성자 - OperatingSystem(objectGetOptions)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="objectGetOptions">객체 GET 옵션</param>
        public OperatingSystem(ObjectGetOptions objectGetOptions)
        {
            InitializeObject(null, new ManagementPath(OperatingSystem.ConstructPath()), objectGetOptions);
        }

        #endregion
        #region 생성자 - OperatingSystem(managementScope, objectGetOptions)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementScope">관리 범위</param>
        /// <param name="objectGetOptions">객체 GET 옵션</param>
        public OperatingSystem(ManagementScope managementScope, ObjectGetOptions objectGetOptions)
        {
            InitializeObject(managementScope, new ManagementPath(OperatingSystem.ConstructPath()), objectGetOptions);
        }

        #endregion
        #region 생성자 - OperatingSystem(managementScope, managementPath, objectGetOptions)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementScope">관리 범위</param>
        /// <param name="managementPath">관리 경로</param>
        /// <param name="objectGetOptions">객체 GET 옵션</param>
        public OperatingSystem(ManagementScope managementScope, ManagementPath managementPath, ObjectGetOptions objectGetOptions)
        {
            InitializeObject(managementScope, managementPath, objectGetOptions);
        }

        #endregion
        #region 생성자 - OperatingSystem(managementObject)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementObject">관리 객체</param>
        public OperatingSystem(ManagementObject managementObject)
        {
            Initialize();

            if(CheckIfProperClass(managementObject))
            {
                this.managementObject = managementObject;

                this.managementSystemProperties = new ManagementSystemProperties(this.managementObject);

                this.currentManagementBaseObject = this.managementObject;
            }
            else
            {
                throw new System.ArgumentException("Class name does not match.");
            }
        }

        #endregion
        #region 생성자 - OperatingSystem(managementBaseObject)

        /// <summary>
        /// 생성자
        /// </summary>
        /// <param name="managementBaseObject">관리 기본 객체</param>
        public OperatingSystem(ManagementBaseObject managementBaseObject)
        {
            Initialize();

            if(CheckIfProperClass(managementBaseObject))
            {
                this.embeddedManagementBaseObject = managementBaseObject;

                this.managementSystemProperties = new ManagementSystemProperties(managementBaseObject);

                this.currentManagementBaseObject = this.embeddedManagementBaseObject;

                this.isEmbedded = true;
            }
            else
            {
                throw new ArgumentException("Class name does not match.");
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 인스턴스 생성하기 - CreateInstance()

        /// <summary>
        /// 인스턴스 생성하기
        /// </summary>
        /// <returns>인스턴스</returns>
        [Browsable(true)]
        public static OperatingSystem CreateInstance()
        {
            ManagementScope managementScope = null;

            if(_managementScope == null)
            {
                managementScope = new ManagementScope();

                managementScope.Path.NamespacePath = _wmiNamespace;
            }
            else
            {
                managementScope = _managementScope;
            }

            ManagementPath managementPath = new ManagementPath(_className);

            ManagementClass managementClass = new ManagementClass(managementScope, managementPath, null);

            return new OperatingSystem(managementClass.CreateInstance());
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Private

        #region 날짜/시간 구하기 - ToDateTime(dmtfDate)

        /// <summary>
        /// 날짜/시간 구하기
        /// </summary>
        /// <param name="dmtfDate">DMTF 일자</param>
        /// <returns>날짜/시간</returns>
        private static DateTime ToDateTime(string dmtfDate)
        {
            DateTime initializer = DateTime.MinValue;

            int    year      = initializer.Year;
            int    month     = initializer.Month;
            int    day       = initializer.Day;
            int    hour      = initializer.Hour;
            int    minute    = initializer.Minute;
            int    second    = initializer.Second;
            long   tickCount = 0;
            string dmtf      = dmtfDate;

            DateTime dateTime = DateTime.MinValue;

            string temporaryString = string.Empty;

            if(dmtf == null)
            {
                throw new ArgumentOutOfRangeException();
            }

            if(dmtf.Length == 0)
            {
                throw new ArgumentOutOfRangeException();
            }

            if(dmtf.Length != 25)
            {
                throw new ArgumentOutOfRangeException();
            }

            try
            {
                temporaryString = dmtf.Substring(0, 4);

                if("****" != temporaryString)
                {
                    year = int.Parse(temporaryString);
                }

                temporaryString = dmtf.Substring(4, 2);

                if("**" != temporaryString)
                {
                    month = int.Parse(temporaryString);
                }

                temporaryString = dmtf.Substring(6, 2);

                if("**" != temporaryString)
                {
                    day = int.Parse(temporaryString);
                }
 
                temporaryString = dmtf.Substring(8, 2);

                if("**" != temporaryString)
                {
                    hour = int.Parse(temporaryString);
                }

                temporaryString = dmtf.Substring(10, 2);

                if("**" != temporaryString)
                {
                    minute = int.Parse(temporaryString);
                }

                temporaryString = dmtf.Substring(12, 2);

                if("**" != temporaryString)
                {
                    second = int.Parse(temporaryString);
                }

                temporaryString = dmtf.Substring(15, 6);

                if("******" != temporaryString)
                {
                    tickCount = long.Parse(temporaryString) * (long)(TimeSpan.TicksPerMillisecond / 1000);
                }

                if((year < 0) || (month < 0) || (day < 0) || (hour < 0) || (minute < 0) || (minute < 0) || (second < 0) || (tickCount < 0))
                {
                    throw new ArgumentOutOfRangeException();
                }
            }
            catch(Exception e)
            {
                throw new ArgumentOutOfRangeException(null, e.Message);
            }

            dateTime = new DateTime(year, month, day, hour, minute, second, 0);

            dateTime = dateTime.AddTicks(tickCount);

            TimeSpan tickOffset = TimeZone.CurrentTimeZone.GetUtcOffset(dateTime);

            int  utcOffset          = 0;
            int  offsetToBeAdjusted = 0;
            long OffsetMinuteCount  = (long)(tickOffset.Ticks / TimeSpan.TicksPerMinute);

            temporaryString = dmtf.Substring(22, 3);

            if(temporaryString != "******")
            {
                temporaryString = dmtf.Substring(21, 4);

                try
                {
                    utcOffset = int.Parse(temporaryString);
                }
                catch(Exception e)
                {
                    throw new ArgumentOutOfRangeException(null, e.Message);
                }

                offsetToBeAdjusted = (int)(OffsetMinuteCount - utcOffset);
                dateTime           = dateTime.AddMinutes((double)offsetToBeAdjusted);
            }

            return dateTime;
        }

        #endregion
        #region DMTF 날짜/시간 구하기 - ToDMTFDateTime(dateTime)

        /// <summary>
        /// DMTF 날짜/시간 구하기
        /// </summary>
        /// <param name="dateTime">날짜/시간</param>
        /// <returns>DMTF 날짜/시간</returns>
        private static string ToDMTFDateTime(DateTime dateTime)
        {
            string utcString = string.Empty;

            TimeSpan tickOffset = TimeZone.CurrentTimeZone.GetUtcOffset(dateTime);

            long OffsetMinuteCount = (long)(tickOffset.Ticks / TimeSpan.TicksPerMinute);

            if(Math.Abs(OffsetMinuteCount) > 999)
            {
                dateTime = dateTime.ToUniversalTime();

                utcString = "+000";
            }
            else
            {
                if(tickOffset.Ticks >= 0)
                {
                    utcString = string.Concat("+", ((long)(tickOffset.Ticks / TimeSpan.TicksPerMinute)).ToString().PadLeft(3, '0'));
                }
                else
                {
                    string strTemporary = ((long)OffsetMinuteCount).ToString();

                    utcString = string.Concat("-", strTemporary.Substring(1, strTemporary.Length - 1).PadLeft(3, '0'));
                }
            }

            string dmtfDateTime = ((int)dateTime.Year).ToString().PadLeft(4, '0');

            dmtfDateTime = string.Concat(dmtfDateTime, ((int)dateTime.Month ).ToString().PadLeft(2, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, ((int)dateTime.Day   ).ToString().PadLeft(2, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, ((int)dateTime.Hour  ).ToString().PadLeft(2, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, ((int)dateTime.Minute).ToString().PadLeft(2, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, ((int)dateTime.Second).ToString().PadLeft(2, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, ".");

            DateTime temporaryDateTime = new DateTime(dateTime.Year, dateTime.Month, dateTime.Day, dateTime.Hour, dateTime.Minute, dateTime.Second, 0);

            long microSecondCount = (long)(((dateTime.Ticks - temporaryDateTime.Ticks) * 1000) / TimeSpan.TicksPerMillisecond);

            string microSecondString = ((long)microSecondCount).ToString();

            if(microSecondString.Length > 6)
            {
                microSecondString = microSecondString.Substring(0, 6);
            }

            dmtfDateTime = string.Concat(dmtfDateTime, microSecondString.PadLeft(6, '0'));
            dmtfDateTime = string.Concat(dmtfDateTime, utcString);

            return dmtfDateTime;
        }

        #endregion

        #region 경로 구축하기 - ConstructPath()

        /// <summary>
        /// 경로 구축하기
        /// </summary>
        /// <returns>경로</returns>
        private static string ConstructPath()
        {
            return "ROOT\\CIMV2:Win32_OperatingSystem=@";
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Instance
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 객체 커밋하기 - CommitObject()

        /// <summary>
        /// 객체 커밋하기
        /// </summary>
        [Browsable(true)]
        public void CommitObject()
        {
            if(this.isEmbedded == false)
            {
                this.managementObject.Put();
            }
        }

        #endregion
        #region 객체 커밋하기 - CommitObject(putOptions)

        /// <summary>
        /// 객체 커밋하기
        /// </summary>
        /// <param name="putOptions">PUT 옵션</param>
        [Browsable(true)]
        public void CommitObject(PutOptions putOptions)
        {
            if(this.isEmbedded == false)
            {
                this.managementObject.Put(putOptions);
            }
        }

        #endregion

        #region 삭제하기 - Delete()

        /// <summary>
        /// 삭제하기
        /// </summary>
        [Browsable(true)]
        public void Delete()
        {
            this.managementObject.Delete();
        }

        #endregion
        #region 리부팅하기 - Reboot()

        /// <summary>
        /// 리부팅하기
        /// </summary>
        /// <returns>처리 결과</returns>
        public uint Reboot()
        {
            if(this.isEmbedded == false)
            {
                ManagementBaseObject inputParameter = null;

                bool enablePrivileges = this.managementObject.Scope.Options.EnablePrivileges;

                this.managementObject.Scope.Options.EnablePrivileges = true;

                ManagementBaseObject outputParameter = this.managementObject.InvokeMethod("Reboot", inputParameter, null);

                this.managementObject.Scope.Options.EnablePrivileges = enablePrivileges;

                return Convert.ToUInt32(outputParameter.Properties["ReturnValue"].Value);
            }
            else
            {
                return Convert.ToUInt32(0);
            }
        }

        #endregion
        #region 날짜/시간 설정하기 - SetDateTime(localDateTime)

        /// <summary>
        /// 날짜/시간 설정하기
        /// </summary>
        /// <param name="localDateTime">지역 날짜/시간</param>
        /// <returns>처리 결과</returns>
        public uint SetDateTime(DateTime localDateTime)
        {
            if(this.isEmbedded == false)
            {
                ManagementBaseObject inputParameter = null;

                bool enablePrivileges = this.managementObject.Scope.Options.EnablePrivileges;

                this.managementObject.Scope.Options.EnablePrivileges = true;

                inputParameter = this.managementObject.GetMethodParameters("SetDateTime");

                inputParameter["LocalDateTime"] = ToDMTFDateTime((DateTime)localDateTime);

                ManagementBaseObject outputParameter = this.managementObject.InvokeMethod("SetDateTime", inputParameter, null);

                this.managementObject.Scope.Options.EnablePrivileges = enablePrivileges;

                return Convert.ToUInt32(outputParameter.Properties["ReturnValue"].Value);
            }
            else
            {
                return Convert.ToUInt32(0);
            }
        }

        #endregion
        #region 셧다운하기 - Shutdown()

        /// <summary>
        /// 셧다운하기
        /// </summary>
        /// <returns>처리 결과</returns>
        public uint Shutdown()
        {
            if(this.isEmbedded == false)
            {
                ManagementBaseObject inputParameter = null;

                bool enablePrivileges = this.managementObject.Scope.Options.EnablePrivileges;

                this.managementObject.Scope.Options.EnablePrivileges = true;

                ManagementBaseObject outputParameter = this.managementObject.InvokeMethod("Shutdown", inputParameter, null);

                this.managementObject.Scope.Options.EnablePrivileges = enablePrivileges;

                return Convert.ToUInt32(outputParameter.Properties["ReturnValue"].Value);
            }
            else
            {
                return Convert.ToUInt32(0);
            }
        }

        #endregion
        #region WIN32 셧다운하기 - WIN32Shutdown(flag, reserved)

        /// <summary>
        /// WIN32 셧다운하기
        /// </summary>
        /// <param name="flag">플래그</param>
        /// <param name="reserved">예약어</param>
        /// <returns>처리 결과</returns>
        public uint WIN32Shutdown(int flag, int reserved)
        {
            if(this.isEmbedded == false)
            {
                ManagementBaseObject inputParameter = null;

                bool enablePrivileges = this.managementObject.Scope.Options.EnablePrivileges;

                this.managementObject.Scope.Options.EnablePrivileges = true;

                inputParameter = this.managementObject.GetMethodParameters("Win32Shutdown");

                inputParameter["Flags"   ] = (int)(flag);
                inputParameter["Reserved"] = (int)(reserved);

                ManagementBaseObject outputParameter = this.managementObject.InvokeMethod("Win32Shutdown", inputParameter, null);

                this.managementObject.Scope.Options.EnablePrivileges = enablePrivileges;

                return Convert.ToUInt32(outputParameter.Properties["ReturnValue"].Value);
            }
            else
            {
                return Convert.ToUInt32(0);
            }
        }

        #endregion
        #region WIN32 셧다운 트랙커 - WIN32ShutdownTracker(comment, flag, reasonCode, timeout)

        /// <summary>
        /// WIN32 셧다운 트랙커
        /// </summary>
        /// <param name="comment">주석</param>
        /// <param name="flag">플래그</param>
        /// <param name="reasonCode">사유 코드</param>
        /// <param name="timeout">타임아웃</param>
        /// <returns>처리 결과</returns>
        public uint WIN32ShutdownTracker(string comment, int flag, uint reasonCode, uint timeout)
        {
            if(this.isEmbedded == false)
            {
                ManagementBaseObject inputParameter = null;

                bool enablePrivileges = this.managementObject.Scope.Options.EnablePrivileges;

                this.managementObject.Scope.Options.EnablePrivileges = true;

                inputParameter = this.managementObject.GetMethodParameters("Win32ShutdownTracker");

                inputParameter["Comment"   ] = (string)(comment);
                inputParameter["Flags"     ] = (int)(flag);
                inputParameter["ReasonCode"] = (uint)(reasonCode);
                inputParameter["Timeout"   ] = (uint)(timeout);

                ManagementBaseObject outputParameter = this.managementObject.InvokeMethod("Win32ShutdownTracker", inputParameter, null);

                this.managementObject.Scope.Options.EnablePrivileges = enablePrivileges;

                return Convert.ToUInt32(outputParameter.Properties["ReturnValue"].Value);
            }
            else
            {
                return Convert.ToUInt32(0);
            }
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////// Private

        #region 적절한 클래스 여부 체크하기 - CheckIfProperClass(managementBaseObject)

        /// <summary>
        /// 적절한 클래스 여부 체크하기
        /// </summary>
        /// <param name="managementBaseObject">관리 기본 객체</param>
        /// <returns>적절한 클래스 여부</returns>
        private bool CheckIfProperClass(ManagementBaseObject managementBaseObject)
        {
            if((managementBaseObject != null)  && (string.Compare(((string)(managementBaseObject["__CLASS"])), this.ManagementClassName, true, CultureInfo.InvariantCulture) == 0))
            {
                return true;
            }
            else
            {
                Array parentClassArray = (Array)(managementBaseObject["__DERIVATION"]);

                if(parentClassArray != null)
                {
                    int count = 0;

                    for(count = 0; count < parentClassArray.Length; count++)
                    {
                        if(string.Compare((string)(parentClassArray.GetValue(count)), this.ManagementClassName, true, CultureInfo.InvariantCulture) == 0)
                        {
                            return true;
                        }
                    }
                }
            }

            return false;
        }

        #endregion
        #region 적절한 클래스 여부 체크하기 - CheckIfProperClass(managementScope, managementPath, objectGetOptions)

        /// <summary>
        /// 적절한 클래스 여부 체크하기
        /// </summary>
        /// <param name="managementScope">관리 범위</param>
        /// <param name="managementPath">관리 경로</param>
        /// <param name="objectGetOptions">객체 GET 옵션</param>
        /// <returns>적절한 클래스 여부</returns>
        private bool CheckIfProperClass(ManagementScope managementScope, ManagementPath managementPath, ObjectGetOptions objectGetOptions)
        {
            if((managementPath != null) && (string.Compare(managementPath.ClassName, this.ManagementClassName, true, CultureInfo.InvariantCulture) == 0))
            {
                return true;
            }
            else
            {
                return CheckIfProperClass(new ManagementObject(managementScope, managementPath, objectGetOptions));
            }
        }

        #endregion

        #region 현재 타임 존 직렬화 여부 구하기 - ShouldSerializeCurrentTimeZone()

        /// <summary>
        /// 현재 타임 존 직렬화 여부 구하기
        /// </summary>
        /// <returns>현재 타임 존 직렬화 여부</returns>
        private bool ShouldSerializeCurrentTimeZone()
        {
            if(IsCurrentTimeZoneNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 32비트 어플리케이션 데이터 실행 금지 직렬화 여부 구하기 - ShouldSerializeDataExecutionPrevention_32BitApplications()

        /// <summary>
        /// 32비트 어플리케이션 데이터 실행 금지 직렬화 여부 구하기
        /// </summary>
        /// <returns>32비트 어플리케이션 데이터 실행 금지 직렬화 여부</returns>
        private bool ShouldSerializeDataExecutionPrevention_32BitApplications()
        {
            if(IsDataExecutionPrevention_32BitApplicationsNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 이용 가능 데이터 실행 금지 직렬화 여부 구하기 - ShouldSerializeDataExecutionPrevention_Available()

        /// <summary>
        /// 이용 가능 데이터 실행 금지 직렬화 여부 구하기
        /// </summary>
        /// <returns>이용 가능 데이터 실행 금지 직렬화 여부</returns>
        private bool ShouldSerializeDataExecutionPrevention_Available()
        {
            if(IsDataExecutionPrevention_AvailableNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 드라이버 데이터 실행 금지 직렬화 여부 구하기 - ShouldSerializeDataExecutionPrevention_Drivers()

        /// <summary>
        /// 드라이버 데이터 실행 금지 직렬화 여부 구하기
        /// </summary>
        /// <returns>드라이버 데이터 실행 금지 직렬화 여부</returns>
        private bool ShouldSerializeDataExecutionPrevention_Drivers()
        {
            if(IsDataExecutionPrevention_DriversNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 지원 정책 데이터 실행 금지 직렬화 여부 구하기 - ShouldSerializeDataExecutionPrevention_SupportPolicy()

        /// <summary>
        /// 지원 정책 데이터 실행 금지 직렬화 여부 구하기
        /// </summary>
        /// <returns>지원 정책 데이터 실행 금지 직렬화 여부</returns>
        private bool ShouldSerializeDataExecutionPrevention_SupportPolicy()
        {
            if(IsDataExecutionPrevention_SupportPolicyNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 디버그 직렬화 여부 구하기 - ShouldSerializeDebug()

        /// <summary>
        /// 디버그 직렬화 여부 구하기
        /// </summary>
        /// <returns>디버그 직렬화 여부</returns>
        private bool ShouldSerializeDebug()
        {
            if(IsDebugNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 설명 리셋하기 - ResetDescription()

        /// <summary>
        /// 설명 리셋하기
        /// </summary>
        private void ResetDescription()
        {
            this.currentManagementBaseObject["Description"] = null;

            if((this.isEmbedded == false) && (this.automaticCommit == true))
            {
                this.managementObject.Put();
            }
        }

        #endregion
        #region 분산 여부 직렬화 여부 구하기 - ShouldSerializeDistributed()

        /// <summary>
        /// 분산 여부 직렬화 여부 구하기
        /// </summary>
        /// <returns>분산 여부 직렬화 여부</returns>
        private bool ShouldSerializeDistributed()
        {
            if(IsDistributedNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 암호화 레벨 직렬화 여부 구하기 - ShouldSerializeEncryptionLevel()

        /// <summary>
        /// 암호화 레벨 직렬화 여부 구하기
        /// </summary>
        /// <returns>암호화 레벨 직렬화 여부</returns>
        private bool ShouldSerializeEncryptionLevel()
        {
            if(IsEncryptionLevelNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 전경 어플리케이션 부스트 직렬화 여부 구하기 - ShouldSerializeForegroundApplicationBoost()

        /// <summary>
        /// 전경 어플리케이션 부스트 직렬화 여부 구하기
        /// </summary>
        /// <returns>전경 어플리케이션 부스트 직렬화 여부</returns>
        private bool ShouldSerializeForegroundApplicationBoost()
        {
            if(IsForegroundApplicationBoostNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 전경 어플리케이션 부스트 리셋하기 - ResetForegroundApplicationBoost()

        /// <summary>
        /// 전경 어플리케이션 부스트 리셋하기
        /// </summary>
        private void ResetForegroundApplicationBoost()
        {
            this.currentManagementBaseObject["ForegroundApplicationBoost"] = null;

            if((this.isEmbedded == false) && (this.automaticCommit == true))
            {
                this.managementObject.Put();
            }
        }

        #endregion
        #region 프리 물리적 메모리 직렬화 여부 구하기 - ShouldSerializeFreePhysicalMemory()

        /// <summary>
        /// 프리 물리적 메모리 직렬화 여부 구하기
        /// </summary>
        /// <returns>프리 물리적 메모리 직렬화 여부</returns>
        private bool ShouldSerializeFreePhysicalMemory()
        {
            if(this.IsFreePhysicalMemoryNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 페이징 파일에서 프리 공간 직렬화 여부 구하기 - ShouldSerializeFreeSpaceInPagingFiles()

        /// <summary>
        /// 페이징 파일에서 프리 공간 직렬화 여부 구하기
        /// </summary>
        /// <returns>페이징 파일에서 프리 공간 직렬화 여부</returns>
        private bool ShouldSerializeFreeSpaceInPagingFiles()
        {
            if(this.IsFreeSpaceInPagingFilesNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 프리 가상 메모리 직렬화 여부 구하기 - ShouldSerializeFreeVirtualMemory()

        /// <summary>
        /// 프리 가상 메모리 직렬화 여부 구하기
        /// </summary>
        /// <returns>프리 가상 메모리 직렬화 여부</returns>
        private bool ShouldSerializeFreeVirtualMemory()
        {
            if(IsFreeVirtualMemoryNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 설치일 직렬화 여부 구하기 - ShouldSerializeInstallDate()

        /// <summary>
        /// 설치일 직렬화 여부 구하기
        /// </summary>
        /// <returns>설치일 직렬화 여부</returns>
        private bool ShouldSerializeInstallDate()
        {
            if(IsInstallDateNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 큰 시스템 캐시 직렬화 여부 구하기 - ShouldSerializeLargeSystemCache()

        /// <summary>
        /// 큰 시스템 캐시 직렬화 여부 구하기
        /// </summary>
        /// <returns>큰 시스템 캐시 직렬화 여부</returns>
        private bool ShouldSerializeLargeSystemCache()
        {
            if(IsLargeSystemCacheNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 마지막 부트 업 시간 직렬화 여부 구하기 - ShouldSerializeLastBootUpTime()

        /// <summary>
        /// 마지막 부트 업 시간 직렬화 여부 구하기
        /// </summary>
        /// <returns>마지막 부트 업 시간 직렬화 여부</returns>
        private bool ShouldSerializeLastBootUpTime()
        {
            if(IsLastBootUpTimeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 지역 날짜/시간 직렬화 여부 구하기 - ShouldSerializeLocalDateTime()

        /// <summary>
        /// 지역 날짜/시간 직렬화 여부 구하기
        /// </summary>
        /// <returns>지역 날짜/시간 직렬화 여부</returns>
        private bool ShouldSerializeLocalDateTime()
        {
            if(IsLocalDateTimeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 최대 프로세스 수 직렬화 여부 구하기 - ShouldSerializeMaximumProcessCount()

        /// <summary>
        /// 최대 프로세스 수 직렬화 여부 구하기
        /// </summary>
        /// <returns>최대 프로세스 수 직렬화 여부</returns>
        private bool ShouldSerializeMaximumProcessCount()
        {
            if(IsMaximumProcessCountNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 최대 프로세스 메모리 크기 직렬화 여부 구하기 - ShouldSerializeMaximumProcessMemorySize()

        /// <summary>
        /// 최대 프로세스 메모리 크기 직렬화 여부 구하기
        /// </summary>
        /// <returns>최대 프로세스 메모리 크기 직렬화 여부</returns>
        private bool ShouldSerializeMaximumProcessMemorySize()
        {
            if(IsMaximumProcessMemorySizeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 라이센스 사용자 수 직렬화 여부 구하기 - ShouldSerializeLicensedUserCount()

        /// <summary>
        /// 라이센스 사용자 수 직렬화 여부 구하기
        /// </summary>
        /// <returns>라이센스 사용자 수 직렬화 여부</returns>
        private bool ShouldSerializeLicensedUserCount()
        {
            if(IsLicensedUserCountNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 프로세스 수 직렬화 여부 구하기 - ShouldSerializeProcessCount()

        /// <summary>
        /// 프로세스 수 직렬화 여부 구하기
        /// </summary>
        /// <returns>프로세스 수 직렬화 여부</returns>
        private bool ShouldSerializeProcessCount()
        {
            if(IsProcessCountNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 사용자 수 직렬화 여부 구하기 - ShouldSerializeUserCount()

        /// <summary>
        /// 사용자 수 직렬화 여부 구하기
        /// </summary>
        /// <returns>사용자 수 직렬화 여부</returns>
        private bool ShouldSerializeUserCount()
        {
            if(IsUserCountNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 운영 체제 SKU 직렬화 여부 구하기 - ShouldSerializeOperatingSystemSKU()

        /// <summary>
        /// 운영 체제 SKU 직렬화 여부 구하기
        /// </summary>
        /// <returns>운영 체제 SKU 직렬화 여부</returns>
        private bool ShouldSerializeOperatingSystemSKU()
        {
            if(IsOperatingSystemSKUNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 운영 체제 언어 직렬화 여부 구하기 - ShouldSerializeOSLanguage()

        /// <summary>
        /// 운영 체제 언어 직렬화 여부 구하기
        /// </summary>
        /// <returns>운영 체제 언어 직렬화 여부</returns>
        private bool ShouldSerializeOSLanguage()
        {
            if(IsOSLanguageNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 운영 체제 제품 슈트 직렬화 여부 구하기 - ShouldSerializeOSProductSuite()

        /// <summary>
        /// 운영 체제 제품 슈트 직렬화 여부 구하기
        /// </summary>
        /// <returns>운영 체제 제품 슈트 직렬화 여부</returns>
        private bool ShouldSerializeOSProductSuite()
        {
            if(IsOSProductSuiteNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 운영 체제 타입 직렬화 여부 구하기 - ShouldSerializeOSType()

        /// <summary>
        /// 운영 체제 타입 직렬화 여부 구하기
        /// </summary>
        /// <returns>운영 체제 타입 직렬화 여부</returns>
        private bool ShouldSerializeOSType()
        {
            if(IsOSTypeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region PAE 이용 가능 여부 직렬화 여부 구하기 - ShouldSerializePAEEnabled()

        /// <summary>
        /// PAE 이용 가능 여부 직렬화 여부 구하기
        /// </summary>
        /// <returns>PAE 이용 가능 여부 직렬화 여부</returns>
        private bool ShouldSerializePAEEnabled()
        {
            if(IsPAEEnabledNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 메인 여부 직렬화 여부 구하기 - ShouldSerializePrimary()

        /// <summary>
        /// 메인 여부 직렬화 여부 구하기
        /// </summary>
        /// <returns>메인 여부 직렬화 여부</returns>
        private bool ShouldSerializePrimary()
        {
            if(IsPrimaryNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 제품 타입 직렬화 여부 구하기 - ShouldSerializeProductType()

        /// <summary>
        /// 제품 타입 직렬화 여부 구하기
        /// </summary>
        /// <returns>제품 타입 직렬화 여부</returns>
        private bool ShouldSerializeProductType()
        {
            if(IsProductTypeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 서비스 팩 메이저 버전 직렬화 여부 구하기 - ShouldSerializeServicePackMajorVersion()

        /// <summary>
        /// 서비스 팩 메이저 버전 직렬화 여부 구하기
        /// </summary>
        /// <returns>서비스 팩 메이저 버전 직렬화 여부</returns>
        private bool ShouldSerializeServicePackMajorVersion()
        {
            if(IsServicePackMajorVersionNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 서비스 팩 마이너 버전 직렬화 여부 구하기 - ShouldSerializeServicePackMinorVersion()

        /// <summary>
        /// 서비스 팩 마이너 버전 직렬화 여부 구하기
        /// </summary>
        /// <returns>서비스 팩 마이너 버전 직렬화 여부</returns>
        private bool ShouldSerializeServicePackMinorVersion()
        {
            if(IsServicePackMinorVersionNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 페이징 파일 저장 크기 직렬화 여부 구하기 - ShouldSerializeSizeStoredInPagingFiles()

        /// <summary>
        /// 페이징 파일 저장 크기 직렬화 여부 구하기
        /// </summary>
        /// <returns>페이징 파일 저장 크기 직렬화 여부</returns>
        private bool ShouldSerializeSizeStoredInPagingFiles()
        {
            if(IsSizeStoredInPagingFilesNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 슈트 마스크 직렬화 여부 구하기 - ShouldSerializeSuiteMask()

        /// <summary>
        /// 슈트 마스크 직렬화 여부 구하기
        /// </summary>
        /// <returns>슈트 마스크 직렬화 여부</returns>
        private bool ShouldSerializeSuiteMask()
        {
            if(IsSuiteMaskNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 전체 스왑 공간 크기 직렬화 여부 구하기 - ShouldSerializeTotalSwapSpaceSize()

        /// <summary>
        /// 전체 스왑 공간 크기 직렬화 여부 구하기
        /// </summary>
        /// <returns>전체 스왑 공간 크기 직렬화 여부</returns>
        private bool ShouldSerializeTotalSwapSpaceSize()
        {
            if(IsTotalSwapSpaceSizeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 전체 가상 메모리 크기 직렬화 여부 구하기 - ShouldSerializeTotalVirtualMemorySize()

        /// <summary>
        /// 전체 가상 메모리 크기 직렬화 여부 구하기
        /// </summary>
        /// <returns>전체 가상 메모리 크기 직렬화 여부</returns>
        private bool ShouldSerializeTotalVirtualMemorySize()
        {
            if(IsTotalVirtualMemorySizeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion
        #region 전체 표시 메모리 크기 직렬화 여부 구하기 - ShouldSerializeTotalVisibleMemorySize()

        /// <summary>
        /// 전체 표시 메모리 크기 직렬화 여부 구하기
        /// </summary>
        /// <returns>전체 표시 메모리 크기 직렬화 여부</returns>
        private bool ShouldSerializeTotalVisibleMemorySize()
        {
            if(IsTotalVisibleMemorySizeNull == false)
            {
                return true;
            }

            return false;
        }

        #endregion

        #region 초기화하기 - Initialize()

        /// <summary>
        /// 초기화하기
        /// </summary>
        private void Initialize()
        {
            this.automaticCommit = true;

            this.isEmbedded = false;
        }

        #endregion
        #region 객체 초기화하기 - InitializeObject(managementScope, managementPath, objectGetOptions)

        /// <summary>
        /// 객체 초기화하기
        /// </summary>
        /// <param name="managementScope">관리 범위</param>
        /// <param name="managementPath">관리 경로</param>
        /// <param name="objectGetOptions">객체 GET 옵션</param>
        private void InitializeObject(ManagementScope managementScope, ManagementPath managementPath, ObjectGetOptions objectGetOptions)
        {
            Initialize();

            if(managementPath != null)
            {
                if(CheckIfProperClass(managementScope, managementPath, objectGetOptions) != true)
                {
                    throw new ArgumentException("Class name does not match.");
                }
            }

            this.managementObject = new ManagementObject(managementScope, managementPath, objectGetOptions);

            this.managementSystemProperties = new ManagementSystemProperties(this.managementObject);

            this.currentManagementBaseObject = this.managementObject;
        }

        #endregion
    }
}